@@ -16,15 +16,15 @@ use Role::Commons -all;
 
 use App::Cmd::Setup -app;
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.7
+Version v1.1.11
 
 =cut
 
-our $VERSION = version->declare("v1.1.7");
+our $VERSION = version->declare("v1.1.11");
 
 =head1 SYNOPSIS
 
