@@ -12,15 +12,15 @@ use Role::Commons -all;
 
 use Boxer::CLI -command;
 
-use namespace::clean;
+use namespace::autoclean 0.16;
 
 =head1 VERSION
 
-Version v1.1.7
+Version v1.1.11
 
 =cut
 
-our $VERSION = version->declare("v1.1.7");
+our $VERSION = version->declare("v1.1.11");
 
 require App::Cmd::Command::commands;
 our @ISA;
